==> smooch_plugin-2.0.27.tar.gz: example/android/app/src/main/kotlin/io/skore/smooch_plugin_example/MainActivity.kt <==
package io.skore.smooch_plugin_example

import android.content.Intent
import android.os.Bundle
import android.util.Log
import io.flutter.app.FlutterActivity
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugins.GeneratedPluginRegistrant

class MainActivity : FlutterActivity() {
    private val tag = MainActivity::class.java.simpleName
    private val stateMethodChannel = "app_state_method_channel"
    private val stateEventChannel = "app_state_event_channel"
    private var eventsSink: EventChannel.EventSink? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        Log.d(tag, "onCreate")
        super.onCreate(savedInstanceState)

        setupMethodChannel()
        setupEventChannel()

        GeneratedPluginRegistrant.registerWith(this)
    }

    override fun onNewIntent(intent: Intent?) {
        Log.d(tag, "onNewIntent")
        super.onNewIntent(intent)
        eventsSink?.success(parseIntentAction(intent))
    }

    override fun onDestroy() {
        Log.d(tag, "onDestroy")
        super.onDestroy()
        eventsSink?.endOfStream()
    }

    private fun parseIntentAction(intent: Intent?) = intent?.run {
        val currentAction = action ?: "unknown"
        val scheme = scheme ?: "unknown"
        val host = data?.host ?: "unknown"

        Log.d(tag, "parseIntentAction() => action: $currentAction scheme: $scheme host: $host")

        if (currentAction == "android.intent.action.START_SMOOCH") {
            action = Intent.ACTION_RUN
        }
        currentAction
    } ?: "unknown"

    private fun setupMethodChannel() {
        MethodChannel(flutterView, stateMethodChannel).setMethodCallHandler { call, result ->
            when (call.method) {
                "getIntentAction" -> result.success(parseIntentAction(intent))
                else -> result.notImplemented()
            }
        }
    }

    private fun setupEventChannel() {
        EventChannel(flutterView, stateEventChannel).setStreamHandler(object : EventChannel.StreamHandler {
            override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
                eventsSink = events
            }

            override fun onCancel(arguments: Any?) {
                eventsSink = null
            }
        })
    }
}

==> smooch_plugin-2.0.31.tar.gz: example/android/app/src/main/kotlin/io/skore/smooch_plugin_example/MainActivity.kt <==
package io.skore.smooch_plugin_example

import android.content.Intent
import android.os.Bundle
import android.util.Log
import io.flutter.embedding.android.FlutterActivity
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugins.GeneratedPluginRegistrant

class MainActivity : FlutterActivity() {
    private val tag = MainActivity::class.java.simpleName
    private val stateMethodChannel = "app_state_method_channel"
    private val stateEventChannel = "app_state_event_channel"
    private var eventsSink: EventChannel.EventSink? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        Log.d(tag, "onCreate")
        super.onCreate(savedInstanceState)

        setupMethodChannel()
        setupEventChannel()
    }

    override fun onNewIntent(intent: Intent) {
        Log.d(tag, "onNewIntent")
        super.onNewIntent(intent)
        eventsSink?.success(parseIntentAction(intent))
    }

    override fun onDestroy() {
        Log.d(tag, "onDestroy")
        super.onDestroy()
        eventsSink?.endOfStream()
    }

    private fun parseIntentAction(intent: Intent?) = intent?.run {
        val currentAction = action ?: "unknown"
        val scheme = scheme ?: "unknown"
        val host = data?.host ?: "unknown"

        Log.d(tag, "parseIntentAction() => action: $currentAction scheme: $scheme host: $host")

        if (currentAction == "android.intent.action.START_SMOOCH") {
            action = Intent.ACTION_RUN
        }
        currentAction
    } ?: "unknown"

    private fun setupMethodChannel() {
        MethodChannel(flutterEngine?.dartExecutor?.binaryMessenger, stateMethodChannel).setMethodCallHandler { call, result ->
            when (call.method) {
                "getIntentAction" -> result.success(parseIntentAction(intent))
                else -> result.notImplemented()
            }
        }
    }

    private fun setupEventChannel() {
        EventChannel(flutterEngine?.dartExecutor?.binaryMessenger, stateEventChannel).setStreamHandler(object : EventChannel.StreamHandler {
            override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
                eventsSink = events
            }

            override fun onCancel(arguments: Any?) {
                eventsSink = null
            }
        })
    }
}
